In order to maintain a clean set of raw data files, these functions help with retrieving the raw data from an online source and caching it.
Usage
download_and_verify(
df_in,
target_dir = getOption("evoland.cachedir"),
overwrite = FALSE
)Arguments
- df_in
Data frame with 'url' and 'md5sum' columns. This can be retrieved from pred_meta_t or intrv_meta_t.
- target_dir
Target directory for downloads, defaults to option
evoland.cachedir- overwrite
Whether to overwrite existing files (default: FALSE)