Creates an lulc_data_t table and validates that it matches the schema.
Usage
as_lulc_data_t(x)
# S3 method for class 'lulc_data_t'
print(x, nrow = 10, ...)
lulc_data_as_rast(self, id_period = NULL)Arguments
- x
An object that can be passed to
data.table::setDT()- nrow
- ...
passed to data.table::print.data.table
- id_period
Integer or vector of integers specifying which periods to retrieve; returned as layers.
Value
A data.table of class "lulc_data_t" with columns:
id_run: Foreign key to runs_tid_period: Foreign key to periods_tid_lulc: Foreign key to lulc_meta_tid_coord: Foreign key to coords_t