Creates a runs_t table that stores the identities, hierarchy, and description of
runs. Defaults to a table with one row with the base id_run := 0. Runs are a
feature that allows one to label data that is either overriding base data (e.g.
predictors being used for forecasting) or produced by a specific model experiment
(e.g. a given allocation of land use change given a set of transition potential
models and allocation parameters).
Usage
as_runs_t(x)
# S3 method for class 'runs_t'
print(x, nrow = 10, ...)
db_active_id_run(self, private, x)Arguments
- x
A list or data.frame coercible to a data.table
- nrow
- ...
passed to data.table::print.data.table